@@ -902,7 +902,7 @@ static libGAP_Obj  libGAP_HdlrFunc8 (
   
   /* Error( "corrupted completion file" ); */
   t_1 = libGAP_GF_Error;
-  libGAP_C_NEW_STRING( t_2, 25, "corrupted completion file" )
+  libGAP_C_NEW_STRING( t_2, 25, "corrupted completion file" );
   libGAP_CALL_1ARGS( t_1, t_2 );
   
  }
@@ -984,7 +984,7 @@ static libGAP_Obj  libGAP_HdlrFunc1 (
       return;
   end ); */
  t_1 = libGAP_GF_BIND__GLOBAL;
- libGAP_C_NEW_STRING( t_2, 22, "CLEAR_HIDDEN_IMP_CACHE" )
+ libGAP_C_NEW_STRING( t_2, 22, "CLEAR_HIDDEN_IMP_CACHE" );
  t_3 = libGAP_NewFunction( libGAP_NameFunc[2], libGAP_NargFunc[2], libGAP_NamsFunc[2], libGAP_HdlrFunc2 );
  libGAP_ENVI_FUNC( t_3 ) = libGAP_CurrLVars;
  t_4 = libGAP_NewBag( libGAP_T_BODY, libGAP_NUMBER_HEADER_ITEMS_BODY*sizeof(libGAP_Obj) );
@@ -1021,7 +1021,7 @@ static libGAP_Obj  libGAP_HdlrFunc1 (
       return with;
   end ); */
  t_1 = libGAP_GF_BIND__GLOBAL;
- libGAP_C_NEW_STRING( t_2, 22, "WITH_HIDDEN_IMPS_FLAGS" )
+ libGAP_C_NEW_STRING( t_2, 22, "WITH_HIDDEN_IMPS_FLAGS" );
  t_3 = libGAP_NewFunction( libGAP_NameFunc[3], libGAP_NargFunc[3], libGAP_NamsFunc[3], libGAP_HdlrFunc3 );
  libGAP_ENVI_FUNC( t_3 ) = libGAP_CurrLVars;
  t_4 = libGAP_NewBag( libGAP_T_BODY, libGAP_NUMBER_HEADER_ITEMS_BODY*sizeof(libGAP_Obj) );
@@ -1059,7 +1059,7 @@ static libGAP_Obj  libGAP_HdlrFunc1 (
       return;
   end ); */
  t_1 = libGAP_GF_BIND__GLOBAL;
- libGAP_C_NEW_STRING( t_2, 15, "CLEAR_IMP_CACHE" )
+ libGAP_C_NEW_STRING( t_2, 15, "CLEAR_IMP_CACHE" );
  t_3 = libGAP_NewFunction( libGAP_NameFunc[4], libGAP_NargFunc[4], libGAP_NamsFunc[4], libGAP_HdlrFunc4 );
  libGAP_ENVI_FUNC( t_3 ) = libGAP_CurrLVars;
  t_4 = libGAP_NewBag( libGAP_T_BODY, libGAP_NUMBER_HEADER_ITEMS_BODY*sizeof(libGAP_Obj) );
@@ -1106,7 +1106,7 @@ static libGAP_Obj  libGAP_HdlrFunc1 (
       return with;
   end ); */
  t_1 = libGAP_GF_BIND__GLOBAL;
- libGAP_C_NEW_STRING( t_2, 15, "WITH_IMPS_FLAGS" )
+ libGAP_C_NEW_STRING( t_2, 15, "WITH_IMPS_FLAGS" );
  t_3 = libGAP_NewFunction( libGAP_NameFunc[5], libGAP_NargFunc[5], libGAP_NamsFunc[5], libGAP_HdlrFunc5 );
  libGAP_ENVI_FUNC( t_3 ) = libGAP_CurrLVars;
  t_4 = libGAP_NewBag( libGAP_T_BODY, libGAP_NUMBER_HEADER_ITEMS_BODY*sizeof(libGAP_Obj) );
@@ -1119,7 +1119,7 @@ static libGAP_Obj  libGAP_HdlrFunc1 (
  
  /* UNBIND_GLOBAL( "RANK_FILTER" ); */
  t_1 = libGAP_GF_UNBIND__GLOBAL;
- libGAP_C_NEW_STRING( t_2, 11, "RANK_FILTER" )
+ libGAP_C_NEW_STRING( t_2, 11, "RANK_FILTER" );
  libGAP_CALL_1ARGS( t_1, t_2 );
  
  /* BIND_GLOBAL( "RANK_FILTER", function ( filter )
@@ -1140,7 +1140,7 @@ static libGAP_Obj  libGAP_HdlrFunc1 (
       return rank;
   end ); */
  t_1 = libGAP_GF_BIND__GLOBAL;
- libGAP_C_NEW_STRING( t_2, 11, "RANK_FILTER" )
+ libGAP_C_NEW_STRING( t_2, 11, "RANK_FILTER" );
  t_3 = libGAP_NewFunction( libGAP_NameFunc[6], libGAP_NargFunc[6], libGAP_NamsFunc[6], libGAP_HdlrFunc6 );
  libGAP_ENVI_FUNC( t_3 ) = libGAP_CurrLVars;
  t_4 = libGAP_NewBag( libGAP_T_BODY, libGAP_NUMBER_HEADER_ITEMS_BODY*sizeof(libGAP_Obj) );
@@ -1158,7 +1158,7 @@ static libGAP_Obj  libGAP_HdlrFunc1 (
  
  /* UNBIND_GLOBAL( "RANK_FILTER_STORE" ); */
  t_1 = libGAP_GF_UNBIND__GLOBAL;
- libGAP_C_NEW_STRING( t_2, 17, "RANK_FILTER_STORE" )
+ libGAP_C_NEW_STRING( t_2, 17, "RANK_FILTER_STORE" );
  libGAP_CALL_1ARGS( t_1, t_2 );
  
  /* BIND_GLOBAL( "RANK_FILTER_STORE", function ( filter )
@@ -1175,7 +1175,7 @@ static libGAP_Obj  libGAP_HdlrFunc1 (
       return rank;
   end ); */
  t_1 = libGAP_GF_BIND__GLOBAL;
- libGAP_C_NEW_STRING( t_2, 17, "RANK_FILTER_STORE" )
+ libGAP_C_NEW_STRING( t_2, 17, "RANK_FILTER_STORE" );
  t_3 = libGAP_NewFunction( libGAP_NameFunc[7], libGAP_NargFunc[7], libGAP_NamsFunc[7], libGAP_HdlrFunc7 );
  libGAP_ENVI_FUNC( t_3 ) = libGAP_CurrLVars;
  t_4 = libGAP_NewBag( libGAP_T_BODY, libGAP_NUMBER_HEADER_ITEMS_BODY*sizeof(libGAP_Obj) );
@@ -1188,7 +1188,7 @@ static libGAP_Obj  libGAP_HdlrFunc1 (
  
  /* UNBIND_GLOBAL( "RANK_FILTER_COMPLETION" ); */
  t_1 = libGAP_GF_UNBIND__GLOBAL;
- libGAP_C_NEW_STRING( t_2, 22, "RANK_FILTER_COMPLETION" )
+ libGAP_C_NEW_STRING( t_2, 22, "RANK_FILTER_COMPLETION" );
  libGAP_CALL_1ARGS( t_1, t_2 );
  
  /* BIND_GLOBAL( "RANK_FILTER_COMPLETION", function ( filter )
@@ -1206,7 +1206,7 @@ static libGAP_Obj  libGAP_HdlrFunc1 (
       return RANK_FILTER_LIST[RANK_FILTER_COUNT - 1];
   end ); */
  t_1 = libGAP_GF_BIND__GLOBAL;
- libGAP_C_NEW_STRING( t_2, 22, "RANK_FILTER_COMPLETION" )
+ libGAP_C_NEW_STRING( t_2, 22, "RANK_FILTER_COMPLETION" );
  t_3 = libGAP_NewFunction( libGAP_NameFunc[8], libGAP_NargFunc[8], libGAP_NamsFunc[8], libGAP_HdlrFunc8 );
  libGAP_ENVI_FUNC( t_3 ) = libGAP_CurrLVars;
  t_4 = libGAP_NewBag( libGAP_T_BODY, libGAP_NUMBER_HEADER_ITEMS_BODY*sizeof(libGAP_Obj) );
@@ -1332,8 +1332,8 @@ static libGAP_Int libGAP_InitLibrary ( libGAP_StructInitInfo * libGAP_module )
  /* record names used in handlers */
  
  /* information for the functions */
- libGAP_C_NEW_STRING( libGAP_DefaultName, 14, "local function" )
- libGAP_C_NEW_STRING( libGAP_FileName, 21, "GAPROOT/lib/filter1.g" )
+ libGAP_C_NEW_STRING( libGAP_DefaultName, 14, "local function" );
+ libGAP_C_NEW_STRING( libGAP_FileName, 21, "GAPROOT/lib/filter1.g" );
  libGAP_NameFunc[1] = libGAP_DefaultName;
  libGAP_NamsFunc[1] = 0;
  libGAP_NargFunc[1] = 0;
