@@ -1203,10 +1203,29 @@ libGAP_Obj libGAP_NewFunctionCT (
     libGAP_ObjFunc             hdlr )
 {
     libGAP_Obj                 name_o;         /* name as an object               */
-    libGAP_Obj                 nams_o;         /* nams as an object               */
-    libGAP_UInt                 len;            /* length                          */
-    libGAP_UInt                 i, k, l;        /* loop variables                  */
 
+    /* convert the name to an object                                       */
+    libGAP_C_NEW_STRING_DYN(name_o, name_c);
+    libGAP_RetypeBag(name_o, libGAP_T_STRING+libGAP_IMMUTABLE);
+
+    /* make the function                                                   */
+    return libGAP_NewFunctionT( type, size, name_o, narg, libGAP_ArgStringToList( nams_c ), hdlr );
+}
+    
+
+/****************************************************************************
+**
+*F  ArgStringToList( <nams_c> )
+**
+** 'ArgStringToList' takes a C string <nams_c> containing a list of comma
+** separated argument names, and turns it into a plist of strings, ready
+** to be passed to 'NewFunction' as <nams>.
+*/
+libGAP_Obj libGAP_ArgStringToList(const libGAP_Char *nams_c) {
+    libGAP_Obj                 tmp;            /* argument name as an object      */
+    libGAP_Obj                 nams_o;         /* nams as an object               */
+    libGAP_UInt                len;            /* length                          */
+    libGAP_UInt                i, k, l;        /* loop variables                  */
 
     /* convert the arguments list to an object                             */
     len = 0;
@@ -1224,23 +1243,18 @@ libGAP_Obj libGAP_NewFunctionCT (
             k++;
         }
         l = k;
-        while ( nams_c[l]!=' ' && nams_c[l]!=',' && nams_c[l]!='\0' ) {
+        while ( nams_c[l] != ' ' && nams_c[l] != ',' && nams_c[l] != '\0' ) {
             l++;
         }
-        libGAP_C_NEW_STRING(name_o, l-k, nams_c+k);
-        libGAP_RESET_FILT_LIST( name_o, libGAP_FN_IS_MUTABLE );
-        libGAP_SET_ELM_PLIST( nams_o, i, name_o );
+        libGAP_C_NEW_STRING( tmp, l - k, nams_c + k );
+        libGAP_RetypeBag( tmp, libGAP_T_STRING+libGAP_IMMUTABLE );
+        libGAP_SET_ELM_PLIST( nams_o, i, tmp );
         k = l;
     }
 
-    /* convert the name to an object                                       */
-    libGAP_C_NEW_STRING_DYN(name_o, name_c);
-    libGAP_RESET_FILT_LIST( name_o, libGAP_FN_IS_MUTABLE );
-
-    /* make the function                                                   */
-    return libGAP_NewFunctionT( type, size, name_o, narg, nams_o, hdlr );
+    return nams_o;
 }
-    
+
 
 /****************************************************************************
 **
@@ -1555,7 +1569,7 @@ libGAP_Obj libGAP_FuncNAME_FUNC (
         name = libGAP_NAME_FUNC(func);
         if ( name == 0 ) {
             libGAP_C_NEW_STRING_CONST(name, "unknown");
-            libGAP_RESET_FILT_LIST( name, libGAP_FN_IS_MUTABLE );
+            libGAP_RetypeBag(name, libGAP_T_STRING+libGAP_IMMUTABLE);
             libGAP_NAME_FUNC(func) = name;
             libGAP_CHANGED_BAG(func);
         }
