@@ -289,6 +289,11 @@ libGAP_Char *          libGAP_NameGVar (
     return libGAP_CSTR_STRING( libGAP_ELM_PLIST( libGAP_NameGVars, gvar ) );
 }
 
+libGAP_Obj libGAP_NameGVarObj ( libGAP_UInt gvar )
+{
+    return libGAP_ELM_PLIST( libGAP_NameGVars, gvar );
+}
+
 
 #define libGAP_NSCHAR '@'
 
